@@ -49,25 +49,17 @@ class CfPostgresql(CfDatabase):
 
         logger.debug('Database connection established.')
 
-    @property
     def connection_status(self) -> str:
         """Return psycopg2 connection status.
 
         Returns:
             Connection status
         """
-        connection_info = psycopg2.extensions.ConnectionInfo()
-
-        if connection_info.status == psycopg2.extensions.TRANSACTION_STATUS_IDLE:
-            return 'Idle'
-        if connection_info.status == psycopg2.extensions.TRANSACTION_STATUS_ACTIVE:
-            return 'Active'
-        if connection_info.status == psycopg2.extensions.TRANSACTION_STATUS_INTRANS:
-            return 'In Transition'
-        if connection_info.status == psycopg2.extensions.TRANSACTION_STATUS_INERROR:
-            return 'In Error'
+        results = self.execute('SELECT version()')
+        if 'PostgreSQL' in results[0]['version']:
+            return 'OK'
         else:
-            return 'Unknown'
+            return 'Error'
 
     @staticmethod
     def split_table_path(table_path: str = None) -> Tuple[str, str]:
@@ -76,8 +68,7 @@ class CfPostgresql(CfDatabase):
         Args:
             table_path: Table name in the form <schema>.<table>
         Returns:
-            schema
-            table
+            schema, table
         """
         if table_path is None:
             raise ValueError('warehouse_table cannot be None.')
@@ -90,20 +81,41 @@ class CfPostgresql(CfDatabase):
 
         return schema, table
 
+    def database_exists(self, database_name: str = None) -> bool:
+        """Test for the existence of a database.
+
+        Args:
+            database_name: Name of the database to search for.
+        Returns:
+            True, if database exists. False, if not.
+        """
+        results = self.execute(f'''
+                    SELECT EXISTS(
+                      SELECT 1
+                      FROM pg_catalog.pg_database
+                      WHERE datname = '{database_name}'
+                    );
+                ''')
+
+        if results[0][0] is not True:
+            return False
+        else:
+            return True
+
     def table_exists(self, table_path: str = None) -> bool:
         """Test for the existence of a schema table.
 
         Args:
             table_path: Table name in the form <schema>.<table>
         Returns:
-            True if table exists. False if not.
+            True, if table exists. False, if not.
         """
         schema, table = self.split_table_path(table_path)
 
         results = self.execute(f'''
             SELECT EXISTS(
               SELECT 1
-              FROM warehouse.pg_catalog.pg_tables
+              FROM pg_catalog.pg_tables
               WHERE schemaname = '{schema}'
               AND tablename = '{table}'
             );
@@ -114,12 +126,14 @@ class CfPostgresql(CfDatabase):
         else:
             return True
 
-    def fields_exist(self, table_path: str = None, table_fields: List = None):
+    def fields_exist(self, table_path: str = None, table_fields: List = None) -> bool:
         """Tests for the existence of table fields.
 
         Args:
             table_path: Table name in the form <schema>.<table>
             table_fields: A list of fields to check.
+        Returns:
+            True, if all fields are present in the table. False, if not.
         """
         schema, table = self.split_table_path(table_path)
 
